/**
 * @since 1.0.0
 */
import { type ApiGatewayManagementApiClient, type ApiGatewayManagementApiClientConfig, type DeleteConnectionCommandInput, type DeleteConnectionCommandOutput, type GetConnectionCommandInput, type GetConnectionCommandOutput, type PostToConnectionCommandInput, type PostToConnectionCommandOutput } from "@aws-sdk/client-apigatewaymanagementapi";
import { Effect, Layer } from "effect";
import { ApiGatewayManagementApiClientInstance } from "./ApiGatewayManagementApiClientInstance";
import { ApiGatewayManagementApiClientInstanceConfig } from "./ApiGatewayManagementApiClientInstanceConfig";
import { ForbiddenError, GoneError, LimitExceededError, PayloadTooLargeError, SdkError } from "./Errors";
/**
 * @since 1.0.0
 */
export interface HttpHandlerOptions {
    /**
     * The maximum time in milliseconds that the connection phase of a request
     * may take before the connection attempt is abandoned.
     */
    requestTimeout?: number;
}
interface ApiGatewayManagementApiService$ {
    readonly _: unique symbol;
    /**
     * @see {@link DeleteConnectionCommand}
     */
    deleteConnection(args: DeleteConnectionCommandInput, options?: HttpHandlerOptions): Effect.Effect<DeleteConnectionCommandOutput, SdkError | ForbiddenError | GoneError | LimitExceededError>;
    /**
     * @see {@link GetConnectionCommand}
     */
    getConnection(args: GetConnectionCommandInput, options?: HttpHandlerOptions): Effect.Effect<GetConnectionCommandOutput, SdkError | ForbiddenError | GoneError | LimitExceededError>;
    /**
     * @see {@link PostToConnectionCommand}
     */
    postToConnection(args: PostToConnectionCommandInput, options?: HttpHandlerOptions): Effect.Effect<PostToConnectionCommandOutput, SdkError | ForbiddenError | GoneError | LimitExceededError | PayloadTooLargeError>;
}
/**
 * @since 1.0.0
 * @category constructors
 */
export declare const makeApiGatewayManagementApiService: Effect.Effect<ApiGatewayManagementApiService$, never, ApiGatewayManagementApiClientInstance>;
declare const ApiGatewayManagementApiService_base: import("effect/Context").TagClass<ApiGatewayManagementApiService, "@effect-aws/client-api-gateway-management-api/ApiGatewayManagementApiService", ApiGatewayManagementApiService$> & {
    readonly _: Effect.Effect<ApiGatewayManagementApiService$["_"], never, ApiGatewayManagementApiService>;
    deleteConnection: (args: DeleteConnectionCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<DeleteConnectionCommandOutput, ForbiddenError | GoneError | LimitExceededError | SdkError, ApiGatewayManagementApiService>;
    getConnection: (args: GetConnectionCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<GetConnectionCommandOutput, ForbiddenError | GoneError | LimitExceededError | SdkError, ApiGatewayManagementApiService>;
    postToConnection: (args: PostToConnectionCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<PostToConnectionCommandOutput, ForbiddenError | GoneError | LimitExceededError | PayloadTooLargeError | SdkError, ApiGatewayManagementApiService>;
} & {
    use: <X>(body: (_: ApiGatewayManagementApiService$) => X) => X extends Effect.Effect<infer A, infer E, infer R> ? Effect.Effect<A, E, R | ApiGatewayManagementApiService> : Effect.Effect<X, never, ApiGatewayManagementApiService>;
};
/**
 * @since 1.0.0
 * @category models
 */
export declare class ApiGatewayManagementApiService extends ApiGatewayManagementApiService_base {
    static readonly defaultLayer: Layer.Layer<ApiGatewayManagementApiService, never, never>;
    static readonly layer: (config: ApiGatewayManagementApiClientConfig) => Layer.Layer<ApiGatewayManagementApiService, never, never>;
    static readonly baseLayer: (evaluate: (defaultConfig: ApiGatewayManagementApiClientConfig) => ApiGatewayManagementApiClient) => Layer.Layer<ApiGatewayManagementApiService, never, never>;
}
/**
 * @since 1.0.0
 * @category models
 * @alias ApiGatewayManagementApiService
 */
export declare const ApiGatewayManagementApi: typeof ApiGatewayManagementApiService;
/**
 * @since 1.0.0
 * @category layers
 * @deprecated use ApiGatewayManagementApi.baseLayer instead
 */
export declare const BaseApiGatewayManagementApiServiceLayer: Layer.Layer<ApiGatewayManagementApiService, never, ApiGatewayManagementApiClientInstance>;
/**
 * @since 1.0.0
 * @category layers
 * @deprecated use ApiGatewayManagementApi.layer instead
 */
export declare const ApiGatewayManagementApiServiceLayer: Layer.Layer<ApiGatewayManagementApiService, never, ApiGatewayManagementApiClientInstanceConfig>;
/**
 * @since 1.0.0
 * @category layers
 * @deprecated use ApiGatewayManagementApi.defaultLayer instead
 */
export declare const DefaultApiGatewayManagementApiServiceLayer: Layer.Layer<ApiGatewayManagementApiService, never, never>;
export {};
